SAPPHIREUI_URL = "https://sapphireui-blue-book.reflex.run/"
SAPPHIREUI_SLOGAN = (
    "Beautifully designed Reflex components to build your web apps faster. Open source."
)
SAPPHIREUI_KEY_WORDS = (
    "sapphire, ui, web apps, framework, open source, frontend, backend, full stack"
)
SITE_LOGO_URL = "https://raw.githubusercontent.com/sapphireUI/SapphireUI/refs/heads/main/assets/site/site_preview.webp"

SITE_META_TAGS = [
    {"name": "application-name", "content": "SapphireUI"},
    {"name": "keywords", "content": SAPPHIREUI_KEY_WORDS},
    {"name": "description", "content": SAPPHIREUI_SLOGAN},
    {"property": "og:url", "content": SAPPHIREUI_URL},
    {"property": "og:type", "content": "website"},
    {"property": "og:title", "content": "SapphireUI"},
    {"property": "og:description", "content": SAPPHIREUI_SLOGAN},
    {"property": "og:image", "content": SITE_LOGO_URL},
    {"property": "og:image:width", "content": "1200"},
    {"property": "og:image:height", "content": "630"},
    {"name": "twitter:card", "content": "summary_large_image"},
    {"property": "twitter:domain", "content": SAPPHIREUI_URL},
    {"property": "twitter:url", "content": SAPPHIREUI_URL},
    {"name": "twitter:title", "content": "SapphireUI"},
    {"name": "twitter:description", "content": SAPPHIREUI_SLOGAN},
    {"name": "twitter:image", "content": SITE_LOGO_URL},
]
